==> owncloud-news_5.3.8%2Bdfsg.orig.tar.gz: news-5.3.8/l10n/da.php <==
<?php
$TRANSLATIONS = array(
"Feed contains invalid XML" => "Feed'et indeholder ugyldig XML",
"Could not find a feed" => "Kunne ikke finde et feed",
"Detected feed format is not supported" => "Det registrerede feed-format understøttes ikke",
"SSL Certificate is invalid" => "SSL-certifikatet er ugyldigt",
"Website not found" => "Hjemmesiden blev ikke fundet",
"More redirects than allowed, aborting" => "Flere videredirigeringer end tilladt - afbryder",
"Bigger than maximum allowed size" => "Større end maksimalt tilladt størrelse",
"Request timed out" => "Forespørgslen nåede tidsudløb",
"Request failed, network connection unavailable!" => "Forespørgslen mislykkedes, netværksforbindelse er ikke tilgængelig!",
"Request unauthorized. Are you logged in?" => "Forespørgslen var ikke autoriseret. Er du logget ind?",
"Request forbidden. Are you an admin?" => "Forespørgslen er ikke tilladt. Er du administrator?",
"Token expired or app not enabled! Reload the page!" => "Tokenet er udløbet eller appen er ikke aktiveret! Genindlæs siden!",
"Internal server error! Please check your " => "Intern serverfejl! Tjek venligst din",
"Request failed, ownCloud is in currently " => "Forespørgslen mislykkedes, ownCloud er i øjeblikket",
"Can not add feed: Exists already" => "Kan ikke tilføje feed: Det eksisterer allerede",
"Articles without feed" => "Artikler uden feed",
"Can not add folder: Exists already" => "Kan ikke tilføje mappe: Den findes allerede",
"Use ownCloud cron for updates" => "Brug ownCloud cron til opdateringer",
"Disable this if you run a custom updater such as the Python updater included in the app" => "Slå denne fra, hvis du kører en brugerdefineret opdateringsfunktion såsom Pythons opdateringsfunktion som indgår i app'en",
"Purge interval" => "Oprydningsinterval",
"Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored" => "Den korteste varighed i sekunder før slettede feeds og mapper bliver fjernet fra databasen; værdier under 60 sekunder bliver ignoreret",
"Maximum read count per feed" => "Det maksimale antal læsninger per feed",
"Defines the maximum amount of articles that can be read per feed which won't be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off completely" => "Definerer det maksimale antal artikler, der kan blive læst per feed, der ikke bliver slettet af oprydningskørslen; hvis gamle artikler vises påny efter at være blevet læst, så forøg værdien; negative værdier såsom -1 vil slå denne funktion helt fra",
"Maximum redirects" => "Maksimum for videredirigeringer",
"How many redirects the feed fetcher should follow" => "Hvor mange videredirigeringer som feed-indhenteren skal følge",
"Maximum feed page size" => "Maksimal størrelse for feed-side",
"Maximum feed size in bytes. If the RSS/Atom page is bigger than this value, the update will be aborted" => "Maksimum for feed-størrelse i bytes. Hvis RSS/Atom-siden er større end denne værdi, så afbrydes opdateringen",
"Feed fetcher timeout" => "Tidsudløb for feed-indhenter",
"Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted" => "Det maksimale antal ventetid målt i sekunder for indlæsning af et RSS- eller Atom-feed; hvis det tager længere tid, så afbrydees opdateringen",
"Explore Service URL" => "Udforsk tjenestens URL",
"If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty" => "Hvis denne angives, så vil tjenestens URL blive forespurgt om visning af feeds in sektionen udforsk feed. For at falde tilbage på den indbyggede udforskningstjeneste, så lad feltet stå tomt",
"Saved" => "Gemt",
"Download" => "Download",
"Close" => "Luk",
"Ajax cron mode detected! Your feeds will not be updated correctly. It is recommended to either use the operating system cron or a custom updater." => "Ajax cron-tilstand er registeret! Dine feeds vil ikke blive opdateret korrekt. Det anbefales at du enten bruger operativsystemets cron eller en brugerdefineret opdateringsfunktion.",
"How to set up the operating system cron" => "Sådan opsætter du cron i operativsystemet",
"How to set up a custom updater (faster and no possible deadlock) " => "Sådan opsætter du en brugerdefineret opdateringsfunktion (hurtigere og ingen mulighed for hårdknuder)",
"Subscribe" => "Abonner",
"Refresh" => "Opdatér",
"No articles available" => "Ingen tilgængelige artikler",
"No unread articles available" => "Ingen tilgængelige ulæste artikler",
"Open website" => "Åbn websted",
"Star article" => "Stjernemarkér artiklen",
"Unstar article" => "Fjern stjerne fra artiklen",
"Keep article unread" => "Bevar artikel ulæst",
"Remove keep article unread" => "Fjern \"bevar artikel ulæst\"",
"by" => "af",
"from" => "fra",
"Play audio" => "Afspil lydfil",
"Download video" => "Hent video",
"Download audio" => "Hent lydfil",
"Keyboard shortcut" => "Tastaturgenvej",
"Description" => "Beskrivelse",
"right" => "højre",
"Jump to next article" => "Gå til næste artikel",
"left" => "venstre",
"Jump to previous article" => "Gå til forrige artikel",
"Toggle star article" => "Slå stjerne for artikel til/fra",
"Star article and jump to next one" => "Stjernemarkér artikel og få til den næste",
"Toggle keep current article unread" => "Slå \"bevar nuværende artikel ulæst\" til/fra",
"Open article in new tab" => "Åbn artikel i en ny fane",
"Toggle expand article in compact view" => "Slå \"udvid artikel i kompakt visning\" til/fra",
"Load next feed" => "Indlæs næste feed",
"Load previous feed" => "Indlæs forrige feed",
"Load next folder" => "Indlæs næste mappe",
"Load previous folder" => "Indlæs forrige mappe",
"Scroll to active navigation entry" => "Rul frem til aktive navigationspost",
"Focus search field" => "Fokuser søgefelt",
"Mark current article's feed/folder read" => "Markér nuværende artikels feed/mappe som læst",
"Web address" => "Web adresse",
"Feed exists already!" => "Feedet findes allerede!",
"Folder" => "Mappe",
"No folder" => "Ingen Mappe",
"New folder" => "Ny mappe",
"Folder name" => "Mappenavn",
"Go back" => "Gå tilbage",
"Folder exists already!" => "Mappen findes allerede!",
"New Folder" => "Ny mappe",
"Create" => "Ny",
"Explore" => "Udforsk",
"Deleted feed" => "Slet feed",
"Undo delete feed" => "Fortryd sletning af feed",
"Rename" => "Omdøb",
"Menu" => "Menu",
"No feed ordering" => "Ingen feedrækkefølge",
"Reversed feed ordering" => "Omvendt feedrækkefølge",
"Normal feed ordering" => "Normal feedrækkefølge",
"Rename feed" => "Omdøb feed",
"Delete feed" => "Slet feed",
"Mark all articles read" => "Markér alle artikler som læste",
"Dismiss" => "Afvis",
"Collapse" => "Sammenfold",
"Deleted folder" => "Slettede mappen",
"Undo delete folder" => "Fortryd sletning af mappe",
"Rename folder" => "Omdøb mappe",
"Delete folder" => "Slet mappe",
"Starred" => "Stjernemarkéret",
"Unread articles" => "Ulæste artikler",
"All articles" => "Alle artikler",
"Settings" => "Indstillinger",
"Keyboard shortcuts" => "Tastaturgenveje",
"Disable mark read through scrolling" => "Slå markér som læst fra når der rulles",
"Compact view" => "Kompakt visning",
"Expand articles on key navigation" => "Udvid artikler ved tastenavigation",
"Show all articles" => "Vis alle artikler",
"Reverse ordering (oldest on top)" => "Vend om på rækkefølgen (ældste øverst)",
"Subscriptions (OPML)" => "Abonnementer (OPML)",
"Import" => "Importer",
"Export" => "Eksportér",
"Error when importing: file does not contain valid OPML" => "Fejl ved import: filen indeholder ingen gyldig OPML-kode",
"Unread/Starred Articles" => "Ulæste/stjernemarkerede artikler",
"Error when importing: file does not contain valid JSON" => "Fejl ved import: filen indeholder ikke gyldig JSON kode"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";

==> owncloud-news_7.0.1%2Bdfsg.orig.tar.gz: news-7.0.1/l10n/da.php <==
<?php
$TRANSLATIONS = array(
"Feed contains invalid XML" => "Feed'et indeholder ugyldig XML",
"Feed not found: either the website does not provide a feed or blocks access. To rule out blocking, try to download the feed on your server's command line using curl: curl http://the-feed.tld" => "Feedet blev ikke fundet: webstedet tilbyder enten ikke et feed eller blokerer adgangen. For at tjekke om der blokeres, så prøv at hente feedet på din gennem din servers kommandolinje med curl: curl http://the-feed.tld",
"Detected feed format is not supported" => "Det registrerede feed-format understøttes ikke",
"SSL Certificate is invalid" => "SSL-certifikatet er ugyldigt",
"Website not found" => "Hjemmesiden blev ikke fundet",
"More redirects than allowed, aborting" => "Flere videredirigeringer end tilladt - afbryder",
"Bigger than maximum allowed size" => "Større end maksimalt tilladt størrelse",
"Request timed out" => "Forespørgslen nåede tidsudløb",
"Request failed, network connection unavailable!" => "Forespørgslen mislykkedes, netværksforbindelse er ikke tilgængelig!",
"Request unauthorized. Are you logged in?" => "Forespørgslen var ikke autoriseret. Er du logget ind?",
"Request forbidden. Are you an admin?" => "Forespørgslen er ikke tilladt. Er du administrator?",
"Token expired or app not enabled! Reload the page!" => "Tokenet er udløbet eller appen er ikke aktiveret! Genindlæs siden!",
"Internal server error! Please check your " => "Intern serverfejl! Tjek venligst din",
"Request failed, ownCloud is in currently " => "Forespørgslen mislykkedes, ownCloud er i øjeblikket",
"Can not add feed: Exists already" => "Kan ikke tilføje feed: Det eksisterer allerede",
"Articles without feed" => "Artikler uden feed",
"Can not add folder: Exists already" => "Kan ikke tilføje mappe: Den findes allerede",
"Use ownCloud cron for updates" => "Brug ownCloud cron til opdateringer",
"Disable this if you run a custom updater such as the Python updater included in the app" => "Slå denne fra, hvis du kører en brugerdefineret opdateringsfunktion såsom Pythons opdateringsfunktion som indgår i app'en",
"Purge interval" => "Oprydningsinterval",
"Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored" => "Den korteste varighed i sekunder før slettede feeds og mapper bliver fjernet fra databasen; værdier under 60 sekunder bliver ignoreret",
"Maximum read count per feed" => "Det maksimale antal læsninger per feed",
"Defines the maximum amount of articles that can be read per feed which won't be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off completely" => "Definerer det maksimale antal artikler, der kan blive læst per feed, der ikke bliver slettet af oprydningskørslen; hvis gamle artikler vises påny efter at være blevet læst, så forøg værdien; negative værdier såsom -1 vil slå denne funktion helt fra",
"Maximum redirects" => "Maksimum for videredirigeringer",
"How many redirects the feed fetcher should follow" => "Hvor mange videredirigeringer som feed-indhenteren skal følge",
"Maximum feed page size" => "Maksimal størrelse for feed-side",
"Maximum feed size in bytes. If the RSS/Atom page is bigger than this value, the update will be aborted" => "Maksimum for feed-størrelse i bytes. Hvis RSS/Atom-siden er større end denne værdi, så afbrydes opdateringen",
"Feed fetcher timeout" => "Tidsudløb for feed-indhenter",
"Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted" => "Det maksimale antal ventetid målt i sekunder for indlæsning af et RSS- eller Atom-feed; hvis det tager længere tid, så afbrydees opdateringen",
"Explore Service URL" => "Udforsk tjenestens URL",
"If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty" => "Hvis denne angives, så vil tjenestens URL blive forespurgt om visning af feeds in sektionen udforsk feed. For at falde tilbage på den indbyggede udforskningstjeneste, så lad feltet stå tomt",
"Saved" => "Gemt",
"Download" => "Download",
"Close" => "Luk",
"Ajax or webcron cron mode detected! Your feeds will not be updated correctly. It is recommended to either use the operating system cron or a custom updater." => "Der er registreret crontilstand for ajax eller webcron! Dine feeds vil ikke blive opdateret korrekt. Det anbefales at du enten bruger operativsystemets cron eller en brugerdefineret opdateringsfunktion.",
"How to set up the operating system cron" => "Sådan opsætter du cron i operativsystemet",
"How to set up a custom updater (faster and no possible deadlock) " => "Sådan opsætter du en brugerdefineret opdateringsfunktion (hurtigere og ingen mulighed for hårdknuder)",
"Subscribe" => "Abonner",
"Refresh" => "Opdatér",
"No articles available" => "Ingen tilgængelige artikler",
"No unread articles available" => "Ingen tilgængelige ulæste artikler",
"Open website" => "Åbn websted",
"Star article" => "Stjernemarkér artiklen",
"Unstar article" => "Fjern stjerne fra artiklen",
"Keep article unread" => "Bevar artikel ulæst",
"Remove keep article unread" => "Fjern \"bevar artikel ulæst\"",
"by" => "af",
"from" => "fra",
"Play audio" => "Afspil lydfil",
"Download video" => "Hent video",
"Download audio" => "Hent lydfil",
"Keyboard shortcut" => "Tastaturgenvej",
"Description" => "Beskrivelse",
"right" => "højre",
"Jump to next article" => "Gå til næste artikel",
"left" => "venstre",
"Jump to previous article" => "Gå til forrige artikel",
"Toggle star article" => "Slå stjerne for artikel til/fra",
"Star article and jump to next one" => "Stjernemarkér artikel og få til den næste",
"Toggle keep current article unread" => "Slå \"bevar nuværende artikel ulæst\" til/fra",
"Open article in new tab" => "Åbn artikel i en ny fane",
"Toggle expand article in compact view" => "Slå \"udvid artikel i kompakt visning\" til/fra",
"Load next feed" => "Indlæs næste feed",
"Load previous feed" => "Indlæs forrige feed",
"Load next folder" => "Indlæs næste mappe",
"Load previous folder" => "Indlæs forrige mappe",
"Scroll to active navigation entry" => "Rul frem til aktive navigationspost",
"Focus search field" => "Fokuser søgefelt",
"Mark current article's feed/folder read" => "Markér nuværende artikels feed/mappe som læst",
"Web address" => "Web adresse",
"Feed exists already!" => "Feedet findes allerede!",
"Folder" => "Mappe",
"No folder" => "Ingen Mappe",
"New folder" => "Ny mappe",
"Folder name" => "Mappenavn",
"Go back" => "Gå tilbage",
"Folder exists already!" => "Mappen findes allerede!",
"New Folder" => "Ny mappe",
"Create" => "Ny",
"Explore" => "Udforsk",
"Deleted feed" => "Slet feed",
"Undo delete feed" => "Fortryd sletning af feed",
"Rename" => "Omdøb",
"Menu" => "Menu",
"Unpin feed from the top" => "Frigør feed fra toppen",
"Pin feed to the top" => "Fastgør feed til toppen",
"No feed ordering" => "Ingen feedrækkefølge",
"Reversed feed ordering" => "Omvendt feedrækkefølge",
"Normal feed ordering" => "Normal feedrækkefølge",
"Enable full text feed fetching" => "Slå hentning af fuld tekst-feeds til",
"Disable full text feed fetching" => "Slå hentning af fuld tekst-feeds fra",
"Rename feed" => "Omdøb feed",
"Delete feed" => "Slet feed",
"Mark all articles read" => "Markér alle artikler som læste",
"Dismiss" => "Afvis",
"Collapse" => "Sammenfold",
"Deleted folder" => "Slettede mappen",
"Undo delete folder" => "Fortryd sletning af mappe",
"Rename folder" => "Omdøb mappe",
"Delete folder" => "Slet mappe",
"Starred" => "Stjernemarkéret",
"Unread articles" => "Ulæste artikler",
"All articles" => "Alle artikler",
"Settings" => "Indstillinger",
"Keyboard shortcuts" => "Tastaturgenveje",
"Disable mark read through scrolling" => "Slå markér som læst fra når der rulles",
"Compact view" => "Kompakt visning",
"Expand articles on key navigation" => "Udvid artikler ved tastenavigation",
"Show all articles" => "Vis alle artikler",
"Reverse ordering (oldest on top)" => "Vend om på rækkefølgen (ældste øverst)",
"Subscriptions (OPML)" => "Abonnementer (OPML)",
"Import" => "Importer",
"Export" => "Eksportér",
"Error when importing: file does not contain valid OPML" => "Fejl ved import: filen indeholder ingen gyldig OPML-kode",
"Unread/Starred Articles" => "Ulæste/stjernemarkerede artikler",
"Error when importing: file does not contain valid JSON" => "Fejl ved import: filen indeholder ikke gyldig JSON kode"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
